@@ -8,7 +8,8 @@ fi
 
 FICHERO="debian-guide-es"
 
-LATEX=latex
+# Nonstopmode is needed to build the package in the autobuilders :) (jfs)
+LATEX="latex -interaction=nonstopmode"
 # LATEX=pdflatex
 
 ./clean.sh || true
